<?php
/**
 * The template to display blog archive
 *
 * @package WordPress
 * @subpackage CASAMIA
 * @since CASAMIA 1.0
 */

/*
Template Name: Blog archive
*/

/**
 * Make page with this template and put it into menu
 * to display posts as blog archive
 * You can setup output parameters (blog style, posts per page, parent category, etc.)
 * in the Theme Options section (under the page content)
 * You can build this page in the WPBakery Page Builder to make custom page layout:
 * just insert %%CONTENT%% in the desired place of content
 */

// Get template page's content
$casamia_content = '';
$casamia_blog_archive_mask = '%%CONTENT%%';
$casamia_blog_archive_subst = sprintf('<div class="blog_archive">%s</div>', $casamia_blog_archive_mask);
if ( have_posts() ) {
	the_post(); 
	if (($casamia_content = apply_filters('the_content', get_the_content())) != '') {
		if (($casamia_pos = strpos($casamia_content, $casamia_blog_archive_mask)) !== false) {
			$casamia_content = preg_replace('/(\<p\>\s*)?'.$casamia_blog_archive_mask.'(\s*\<\/p\>)/i', $casamia_blog_archive_subst, $casamia_content);
		} else
			$casamia_content .= $casamia_blog_archive_subst;
		$casamia_content = explode($casamia_blog_archive_mask, $casamia_content);
		// Add VC custom styles to the inline CSS
		$vc_custom_css = get_post_meta( get_the_ID(), '_wpb_shortcodes_custom_css', true );
		if ( !empty( $vc_custom_css ) ) casamia_add_inline_css(strip_tags($vc_custom_css));
	}
}

// Prepare args for a new query
$casamia_args = array(
	'post_status' => current_user_can('read_private_pages') && current_user_can('read_private_posts') ? array('publish', 'private') : 'publish'
);
$casamia_args = casamia_query_add_posts_and_cats($casamia_args, '', casamia_get_theme_option('post_type'), casamia_get_theme_option('parent_cat'));
$casamia_page_number = get_query_var('paged') ? get_query_var('paged') : (get_query_var('page') ? get_query_var('page') : 1);
if ($casamia_page_number > 1) {
	$casamia_args['paged'] = $casamia_page_number;
	$casamia_args['ignore_sticky_posts'] = true;
}
$casamia_ppp = casamia_get_theme_option('posts_per_page');
if ((int) $casamia_ppp != 0)
	$casamia_args['posts_per_page'] = (int) $casamia_ppp;
// Make a new query
query_posts( $casamia_args );
// Set a new query as main WP Query
$GLOBALS['wp_the_query'] = $GLOBALS['wp_query'];

// Set query vars in the new query!
if (is_array($casamia_content) && count($casamia_content) == 2) {
	set_query_var('blog_archive_start', $casamia_content[0]);
	set_query_var('blog_archive_end', $casamia_content[1]);
}

get_template_part('index');
?>