<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage CASAMIA
 * @since CASAMIA 1.0
 */

$casamia_blog_style = explode('_', casamia_get_theme_option('blog_style'));
$casamia_columns = empty($casamia_blog_style[1]) ? 1 : max(1, $casamia_blog_style[1]);
$casamia_expanded = !casamia_sidebar_present() && casamia_is_on(casamia_get_theme_option('expand_content'));
$casamia_post_format = get_post_format();
$casamia_post_format = empty($casamia_post_format) ? 'standard' : str_replace('post-format-', '', $casamia_post_format);
$casamia_animation = casamia_get_theme_option('blog_animation');

?><article id="post-<?php the_ID(); ?>" 
	<?php post_class( 'post_item post_layout_chess post_layout_chess_'.esc_attr($casamia_columns).' post_format_'.esc_attr($casamia_post_format) ); ?>
	<?php echo (!casamia_is_off($casamia_animation) ? ' data-animation="'.esc_attr(casamia_get_animation_classes($casamia_animation)).'"' : ''); ?>>

	<?php
	// Add anchor
	if ($casamia_columns == 1 && shortcode_exists('trx_sc_anchor')) {
		echo do_shortcode('[trx_sc_anchor id="post_'.esc_attr(get_the_ID()).'" title="'.esc_attr(get_the_title()).'"]');
	}

	// Sticky label
	if ( is_sticky() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

	// Featured image
	casamia_show_post_featured( array(
											'class' => $casamia_columns == 1 ? 'casamia-full-height' : '',
											'show_no_image' => true,
											'thumb_bg' => true,
											'thumb_size' => casamia_get_thumb_size(
																	strpos(casamia_get_theme_option('body_style'), 'full')!==false
																		? ( $casamia_columns > 1 ? 'huge' : 'original' )
																		: (	$casamia_columns > 2 ? 'big' : 'huge')
																	)
											) 
										);

	?><div class="post_inner"><div class="post_inner_content"><?php 

		?><div class="post_header entry-header"><?php 

			
			do_action('casamia_action_before_post_meta'); 

			// Post meta
			$casamia_components = casamia_is_inherit(casamia_get_theme_option_from_meta('meta_parts')) 
										? 'categories,date'.($casamia_columns < 3 ? ',counters' : '').($casamia_columns == 1 ? ',edit' : '')
										: casamia_array_get_keys_by_value(casamia_get_theme_option('meta_parts'));
			$casamia_counters = casamia_is_inherit(casamia_get_theme_option_from_meta('counters')) 
										? 'comments'
										: casamia_array_get_keys_by_value(casamia_get_theme_option('counters'));
			$casamia_post_meta = empty($casamia_components) 
										? '' 
										: casamia_show_post_meta(apply_filters('casamia_filter_post_meta_args', array(
												'components' => $casamia_components,
												'counters' => $casamia_counters,
												'seo' => false,
												'echo' => false
												), $casamia_blog_style[0], $casamia_columns)
											);
			casamia_show_layout($casamia_post_meta);

				do_action('casamia_action_before_post_title');

				// Post title
				the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
		?></div><!-- .entry-header -->
	
		<div class="post_content entry-content">
			<div class="post_content_inner">
				<?php
				$casamia_show_learn_more = !in_array($casamia_post_format, array('link', 'aside', 'status', 'quote'));
				if (has_excerpt()) {
					the_excerpt();
				} else if (strpos(get_the_content('!--more'), '!--more')!==false) {
					the_content( '' );
				} else if (in_array($casamia_post_format, array('link', 'aside', 'status'))) {
					the_content();
				} else if ($casamia_post_format == 'quote') {
					if (($quote = casamia_get_tag(get_the_content(), '<blockquote>', '</blockquote>'))!='')
						casamia_show_layout(wpautop($quote));
					else
						the_excerpt();
				} else if (substr(get_the_content(), 0, 1)!='[') {
					the_excerpt();
				}
				?>
			</div>
			<?php
			// Post meta
			if (in_array($casamia_post_format, array('link', 'aside', 'status', 'quote'))) {
				casamia_show_layout($casamia_post_meta);
			}
			// More button
			if ( $casamia_show_learn_more ) {
				?><p><a class="more-link" href="<?php echo esc_url(get_permalink()); ?>"><?php esc_html_e('Read more', 'casamia'); ?></a></p><?php
			}
			?>
		</div><!-- .entry-content -->

	</div></div><!-- .post_inner -->

</article>