<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage CASAMIA
 * @since CASAMIA 1.0
 */

$casamia_blog_style = explode('_', casamia_get_theme_option('blog_style'));
$casamia_columns = empty($casamia_blog_style[1]) ? 2 : max(2, $casamia_blog_style[1]);
$casamia_expanded = !casamia_sidebar_present() && casamia_is_on(casamia_get_theme_option('expand_content'));
$casamia_post_format = get_post_format();
$casamia_post_format = empty($casamia_post_format) ? 'standard' : str_replace('post-format-', '', $casamia_post_format);
$casamia_animation = casamia_get_theme_option('blog_animation');
$casamia_components = casamia_is_inherit(casamia_get_theme_option_from_meta('meta_parts')) 
							? 'categories,date,counters'.($casamia_columns < 3 ? ',edit' : '')
							: casamia_array_get_keys_by_value(casamia_get_theme_option('meta_parts'));
$casamia_counters = casamia_is_inherit(casamia_get_theme_option_from_meta('counters')) 
							? 'comments'
							: casamia_array_get_keys_by_value(casamia_get_theme_option('counters'));

?><div class="<?php casamia_show_layout($casamia_blog_style[0] == 'classic' ? 'column' : 'masonry_item masonry_item'); ?>-1_<?php echo esc_attr($casamia_columns); ?>"><article id="post-<?php the_ID(); ?>"
	<?php post_class( 'post_item post_format_'.esc_attr($casamia_post_format)
					. ' post_layout_classic post_layout_classic_'.esc_attr($casamia_columns)
					. ' post_layout_'.esc_attr($casamia_blog_style[0]) 
					. ' post_layout_'.esc_attr($casamia_blog_style[0]).'_'.esc_attr($casamia_columns)
					); ?>
	<?php echo (!casamia_is_off($casamia_animation) ? ' data-animation="'.esc_attr(casamia_get_animation_classes($casamia_animation)).'"' : ''); ?>>
	<?php

	// Sticky label
	if ( is_sticky() && !is_paged() ) {
		?><span class="post_label label_sticky"></span><?php
	}

	// Featured image
	casamia_show_post_featured( array( 'thumb_size' => casamia_get_thumb_size($casamia_blog_style[0] == 'classic'
													? (strpos(casamia_get_theme_option('body_style'), 'full')!==false 
															? ( $casamia_columns > 2 ? 'big' : 'huge' )
															: (	$casamia_columns > 2
																? ($casamia_expanded ? 'med' : 'small')
																: ($casamia_expanded ? 'big' : 'med')
																)
														)
													: (strpos(casamia_get_theme_option('body_style'), 'full')!==false 
															? ( $casamia_columns > 2 ? 'masonry-big' : 'full' )
															: (	$casamia_columns <= 2 && $casamia_expanded ? 'masonry-big' : 'masonry')
														)
								) ) );

	if ( !in_array($casamia_post_format, array('link', 'aside', 'status', 'quote')) ) {
		?>
		<div class="post_header entry-header">
			<?php

			do_action('casamia_action_before_post_meta');

			// Post meta
			if (!empty($casamia_components))
				casamia_show_post_meta(apply_filters('casamia_filter_post_meta_args', array(
						'components' => $casamia_components,
						'counters' => $casamia_counters,
						'seo' => false
					), $casamia_blog_style[0], $casamia_columns)
				);

			do_action('casamia_action_after_post_meta');

			do_action('casamia_action_before_post_title'); 

			// Post title
			the_title( sprintf( '<h5 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h5>' );


			?>
		</div><!-- .entry-header -->
		<?php
	}		
	?>

	<div class="post_content entry-content">
		<div class="post_content_inner">
			<?php
			$casamia_show_learn_more = false;
			if (has_excerpt()) {
				the_excerpt();
			} else if (strpos(get_the_content('!--more'), '!--more')!==false) {
				the_content( '' );
			} else if (in_array($casamia_post_format, array('link', 'aside', 'status'))) {
				the_content();
			} else if ($casamia_post_format == 'quote') {
				if (($quote = casamia_get_tag(get_the_content(), '<blockquote>', '</blockquote>'))!='')
					casamia_show_layout(wpautop($quote));
				else
					the_excerpt();
			} else if (substr(get_the_content(), 0, 1)!='[') {
				the_excerpt();
			}
			?>
		</div>

		<div class="post_footer">
			<a class="more-link2" href="<?php echo esc_url(get_permalink()); ?>"><?php esc_html_e('Read more', 'casamia'); ?></a>

			<?php
			// Post meta
			$casamia_components = casamia_is_inherit(casamia_get_theme_option_from_meta('meta_parts'))
				? 'categories,date,counters,edit'
				: casamia_array_get_keys_by_value(casamia_get_theme_option('meta_parts'));
			$casamia_counters = casamia_is_inherit(casamia_get_theme_option_from_meta('counters'))
				? 'views,likes,comments'
				: casamia_array_get_keys_by_value(casamia_get_theme_option('counters'));

			if (!empty($casamia_components))
				casamia_show_post_meta(apply_filters('casamia_filter_post_meta_args', array(
						'components' => $casamia_components,
						'counters' => $casamia_counters,
						'seo' => false
					), 'excerpt', 1)
				);
			?>

		</div>


	</div><!-- .entry-content -->

</article></div>