<?php
/**
 * The default template to display the content of the single post, page or attachment
 *
 * Used for index/archive/search.
 *
 * @package WordPress
 * @subpackage CASAMIA
 * @since CASAMIA 1.0
 */

$casamia_seo = casamia_is_on(casamia_get_theme_option('seo_snippets'));
?>

<article id="post-<?php the_ID(); ?>" <?php post_class( 'post_item_single post_type_'.esc_attr(get_post_type()) 
												. ' post_format_'.esc_attr(str_replace('post-format-', '', get_post_format())) 
												);
		if ($casamia_seo) {
			?> itemscope="itemscope" 
			   itemprop="mainEntityOfPage" 
			   itemtype="//schema.org/<?php echo esc_attr(casamia_get_markup_schema()); ?>"
			   itemid="<?php echo esc_url(get_the_permalink()); ?>"
			   content="<?php the_title_attribute(); ?>"<?php
		}
?>><?php

	do_action('casamia_action_before_post_data'); 

	// Structured data snippets
	if ($casamia_seo)
		get_template_part('templates/seo');

	// Featured image
	if ( casamia_is_off(casamia_get_theme_option('hide_featured_on_single'))
			&& !casamia_sc_layouts_showed('featured') 
			&& strpos(get_the_content(), '[trx_widget_banner]')===false) {
		do_action('casamia_action_before_post_featured'); 
		casamia_show_post_featured();
		do_action('casamia_action_after_post_featured'); 
	} else if (has_post_thumbnail()) {
		?><meta itemprop="image" "//schema.org/ImageObject" content="<?php echo esc_url(wp_get_attachment_url(get_post_thumbnail_id())); ?>"><?php
	}

	// Title and post meta
	if ( (!casamia_sc_layouts_showed('title') || !casamia_sc_layouts_showed('postmeta')) && !in_array(get_post_format(), array('link', 'aside', 'status', 'quote')) ) {
		do_action('casamia_action_before_post_title'); 
		?>
		<div class="post_header entry-header">
			<?php
			// Post title
			if (!casamia_sc_layouts_showed('title')) {
				the_title( '<h3 class="post_title entry-title"'.($casamia_seo ? ' itemprop="headline"' : '').'>', '</h3>' );
			}
			// Post meta
			if (!casamia_sc_layouts_showed('postmeta') && casamia_is_on(casamia_get_theme_option('show_post_meta'))) {
				casamia_show_post_meta(apply_filters('casamia_filter_post_meta_args', array(
					'components' => casamia_array_get_keys_by_value(casamia_get_theme_option('meta_parts')),
					'counters' => casamia_array_get_keys_by_value(casamia_get_theme_option('counters')),
					'seo' => casamia_is_on(casamia_get_theme_option('seo_snippets'))
					), 'single', 1)
				);
			}
			?>
		</div><!-- .post_header -->
		<?php
		do_action('casamia_action_after_post_title'); 
	}

	do_action('casamia_action_before_post_content'); 

	// Post content
	?>
	<div class="post_content entry-content" itemprop="articleBody">
		<div class="content-block"><?php
		the_content( );?></div><?php

		do_action('casamia_action_before_post_pagination'); 

		wp_link_pages( array(
			'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'casamia' ) . '</span>',
			'after'       => '</div>',
			'link_before' => '<span>',
			'link_after'  => '</span>',
			'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'casamia' ) . ' </span>%',
			'separator'   => '<span class="screen-reader-text">, </span>',
		) );

		?><div class="post_footer"><?php
			do_action('casamia_action_before_post_meta');

			// Post meta
			$casamia_components = casamia_is_inherit(casamia_get_theme_option_from_meta('meta_parts'))
				? 'categories,date,counters,edit'
				: casamia_array_get_keys_by_value(casamia_get_theme_option('meta_parts'));
			$casamia_counters = casamia_is_inherit(casamia_get_theme_option_from_meta('counters'))
				? 'views,likes,comments'
				: casamia_array_get_keys_by_value(casamia_get_theme_option('counters'));

			if (!empty($casamia_components))
				casamia_show_post_meta(apply_filters('casamia_filter_post_meta_args', array(
						'components' => $casamia_components,
						'counters' => $casamia_counters,
						'seo' => false
					), 'excerpt', 1)
				);
			?></div><?php

		// Taxonomies and share
		if ( is_single() && !is_attachment() ) {

			do_action('casamia_action_before_post_meta'); 

			?><div class="post_meta post_meta_single"><?php
				


				// Share
				if (casamia_is_on(casamia_get_theme_option('show_share_links'))) {
					casamia_show_share_links(array(
							'type' => 'block',
							'caption' => 'Share:',
							'before' => '<div class="post_meta_item post_share">',
							'after' => '</div>'
						));
				}

			// Post taxonomies
			the_tags( '<span class="post_meta_item post_tags"><span class="post_meta_label">'.esc_html__('Tags:', 'casamia').'</span> ', ', ', '</span>' );

			?></div><?php

			do_action('casamia_action_after_post_meta'); 
		}
		?>
	</div><!-- .entry-content -->
	


</article>
<?php
do_action('casamia_action_after_post_content');

// Author bio.
if ( casamia_get_theme_option('show_author_info')==1 && is_single() && !is_attachment() && get_the_author_meta( 'description' ) ) {	
	do_action('casamia_action_before_post_author');
	get_template_part( 'templates/author-bio' );
	do_action('casamia_action_after_post_author');
}

do_action('casamia_action_after_post_data');
?>
