<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage CASAMIA
 * @since CASAMIA 1.0
 */

casamia_storage_set('blog_archive', true);

// Load scripts for both 'Gallery' and 'Portfolio' layouts!
wp_enqueue_script( 'imagesloaded' );
wp_enqueue_script( 'masonry' );
wp_enqueue_script( 'classie', casamia_get_file_url('js/theme.gallery/classie.min.js'), array(), null, true );
wp_enqueue_script( 'casamia-gallery-script', casamia_get_file_url('js/theme.gallery/theme.gallery.js'), array(), null, true );

get_header(); 

if (have_posts()) {

	echo get_query_var('blog_archive_start');

	$casamia_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$casamia_sticky_out = casamia_get_theme_option('sticky_style')=='columns' 
							&& is_array($casamia_stickies) && count($casamia_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$casamia_cat = casamia_get_theme_option('parent_cat');
	$casamia_post_type = casamia_get_theme_option('post_type');
	$casamia_taxonomy = casamia_get_post_type_taxonomy($casamia_post_type);
	$casamia_show_filters = casamia_get_theme_option('show_filters');
	$casamia_tabs = array();
	if (!casamia_is_off($casamia_show_filters)) {
		$casamia_args = array(
			'type'			=> $casamia_post_type,
			'child_of'		=> $casamia_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $casamia_taxonomy,
			'pad_counts'	=> false
		);
		$casamia_portfolio_list = get_terms($casamia_args);
		if (is_array($casamia_portfolio_list) && count($casamia_portfolio_list) > 0) {
			$casamia_tabs[$casamia_cat] = esc_html__('All', 'casamia');
			foreach ($casamia_portfolio_list as $casamia_term) {
				if (isset($casamia_term->term_id)) $casamia_tabs[$casamia_term->term_id] = $casamia_term->name;
			}
		}
	}
	if (count($casamia_tabs) > 0) {
		$casamia_portfolio_filters_ajax = true;
		$casamia_portfolio_filters_active = $casamia_cat;
		$casamia_portfolio_filters_id = 'portfolio_filters';
		if (!is_customize_preview())
			wp_enqueue_script('jquery-ui-tabs', false, array('jquery', 'jquery-ui-core'), null, true);
		?>
		<div class="portfolio_filters casamia_tabs casamia_tabs_ajax">
			<ul class="portfolio_titles casamia_tabs_titles">
				<?php
				foreach ($casamia_tabs as $casamia_id=>$casamia_title) {
					?><li><a href="<?php echo esc_url(casamia_get_hash_link(sprintf('#%s_%s_content', $casamia_portfolio_filters_id, $casamia_id))); ?>" data-tab="<?php echo esc_attr($casamia_id); ?>"><?php echo esc_html($casamia_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$casamia_ppp = casamia_get_theme_option('posts_per_page');
			if (casamia_is_inherit($casamia_ppp)) $casamia_ppp = '';
			foreach ($casamia_tabs as $casamia_id=>$casamia_title) {
				$casamia_portfolio_need_content = $casamia_id==$casamia_portfolio_filters_active || !$casamia_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $casamia_portfolio_filters_id, $casamia_id)); ?>"
					class="portfolio_content casamia_tabs_content"
					data-blog-template="<?php echo esc_attr(casamia_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(casamia_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($casamia_ppp); ?>"
					data-post-type="<?php echo esc_attr($casamia_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($casamia_taxonomy); ?>"
					data-cat="<?php echo esc_attr($casamia_id); ?>"
					data-parent-cat="<?php echo esc_attr($casamia_cat); ?>"
					data-need-content="<?php echo (false===$casamia_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($casamia_portfolio_need_content) 
						casamia_show_portfolio_posts(array(
							'cat' => $casamia_id,
							'parent_cat' => $casamia_cat,
							'taxonomy' => $casamia_taxonomy,
							'post_type' => $casamia_post_type,
							'page' => 1,
							'sticky' => $casamia_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		casamia_show_portfolio_posts(array(
			'cat' => $casamia_cat,
			'parent_cat' => $casamia_cat,
			'taxonomy' => $casamia_taxonomy,
			'post_type' => $casamia_post_type,
			'page' => 1,
			'sticky' => $casamia_sticky_out
			)
		);
	}

	echo get_query_var('blog_archive_end');

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>