<?php
/**
 * Setup theme-specific fonts and colors
 *
 * @package WordPress
 * @subpackage CASAMIA
 * @since CASAMIA 1.0.22
 */

if (!defined("CASAMIA_THEME_FREE")) define("CASAMIA_THEME_FREE", false);

// Theme storage
$CASAMIA_STORAGE = array(
	// Theme required plugin's slugs
	'required_plugins' => array_merge(

		// List of plugins for both - FREE and PREMIUM versions
		//-----------------------------------------------------
		array(
			// Required plugins
			// DON'T COMMENT OR REMOVE NEXT LINES!
			'trx_addons'					=> esc_html__('ThemeREX Addons', 'casamia'),
			
			// Recommended (supported) plugins
			// If plugin not need - comment (or remove) it
			'contact-form-7'				=> esc_html__('Contact Form 7', 'casamia'),
			'instagram-feed'				=> esc_html__('Instagram Feed', 'casamia'),
			'vc-extensions-bundle'			=> esc_html__('WPBakery Page Builder extensions bundle', 'casamia'),
			'mailchimp-for-wp'				=> esc_html__('MailChimp for WP', 'casamia'),
			'woocommerce'					=> esc_html__('WooCommerce', 'casamia'),
            'elegro-payment'                => esc_html__('elegro Crypto Payment', 'casamia'),
            'trx_updater'					=> esc_html__('ThemeREX Updater', 'casamia')
		),

		// List of plugins for PREMIUM version only
		//-----------------------------------------------------
		CASAMIA_THEME_FREE ? array() : array(

			// Recommended (supported) plugins
			// If plugin not need - comment (or remove) it
			'booked'						=> esc_html__('Booked Appointments', 'casamia'),
			'js_composer'					=> esc_html__('WPBakery Page Builder', 'casamia'),
			'essential-grid'				=> esc_html__('Essential Grid', 'casamia'),
			'revslider'						=> esc_html__('Revolution Slider', 'casamia'),
			'prop-plugin'					=> esc_html__('Custom Search for Properties', 'casamia'),
            'wp-gdpr-compliance'            => esc_html__('WP GDPR Compliance', 'casamia'),
		)
	),
	
	// Theme-specific URLs (will be escaped in place of the output)
    'theme_pro_key'      => 'env-ancora',
	'theme_demo_url' => 'http://casamia.ancorathemes.com',
	'theme_doc_url' => 'http://casamia.ancorathemes.com/doc',
	'theme_support_url' => 'https://themerex.net/support/',
    'theme_download_url'=> 'https://1.envato.market/c/1262870/275988/4415?subId1=ancora&u=themeforest.net/item/casamia-property-rental-wordpress-theme/20992167',
);

// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)

if ( !function_exists('casamia_customizer_theme_setup1') ) {
	add_action( 'after_setup_theme', 'casamia_customizer_theme_setup1', 1 );
	function casamia_customizer_theme_setup1() {

		// -----------------------------------------------------------------
		// -- ONLY FOR PROGRAMMERS, NOT FOR CUSTOMER
		// -- Internal theme settings
		// -----------------------------------------------------------------
		casamia_storage_set('settings', array(
			
			'duplicate_options'		=> 'child',		// none  - use separate options for template and child-theme
													// child - duplicate theme options from the main theme to the child-theme only
													// both  - sinchronize changes in the theme options between main and child themes
			
			'custmize_refresh'		=> 'auto',		// Refresh method for preview area in the Appearance - Customize:
													// auto - refresh preview area on change each field with Theme Options
													// manual - refresh only obn press button 'Refresh' at the top of Customize frame
		
			'max_load_fonts'		=> 5,			// Max fonts number to load from Google fonts or from uploaded fonts
		
			'comment_maxlength'		=> 1000,		// Max length of the message from contact form

			'comment_after_name'	=> true,		// Place 'comment' field before the 'name' and 'email'
			
			'socials_type'			=> 'icons',		// Type of socials:
													// icons - use font icons to present social networks
													// images - use images from theme's folder trx_addons/css/icons.png
			
			'icons_type'			=> 'icons',		// Type of other icons:
													// icons - use font icons to present icons
													// images - use images from theme's folder trx_addons/css/icons.png
			
			'icons_selector'		=> 'internal',	// Icons selector in the shortcodes:
													// standard VC icons selector (very slow and don't support images)
													// internal - internal popup with plugin's or theme's icons list (fast)
			'disable_jquery_ui'		=> false,		// Prevent loading custom jQuery UI libraries in the third-party plugins
		
			'use_mediaelements'		=> true,		// Load script "Media Elements" to play video and audio
			
			'tgmpa_upload'			=> false,		// Allow upload not pre-packaged plugins via TGMPA
			
			'allow_theme_layouts'	=> false		// Include theme's default headers and footers to the list after custom layouts
													// or leave in the list only custom layouts
		));


		// -----------------------------------------------------------------
		// -- Theme fonts (Google and/or custom fonts)
		// -----------------------------------------------------------------
		
		// Fonts to load when theme start
		// It can be Google fonts or uploaded fonts, placed in the folder /css/font-face/font-name inside the theme folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		
		casamia_storage_set('load_fonts', array(
			// Google font
			array(
				'name'	 => 'Montserrat',
				'family' => 'sans-serif',
				'styles' => '300,400,500,700'		// Parameter 'style' used only for the Google fonts
				),
			array(
				'name'	 => 'Satisfy',
				'family' => 'cursive',
				'styles' => '400'		// Parameter 'style' used only for the Google fonts
			)
		));
		
		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		casamia_storage_set('load_fonts_subset', 'latin,latin-ext');
		
		// Settings of the main tags
		casamia_storage_set('theme_fonts', array(
			'p' => array(
				'title'				=> esc_html__('Main text', 'casamia'),
				'description'		=> esc_html__('Font settings of the main text of the site', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '1rem',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '0.2px',
				'margin-top'		=> '0em',
				'margin-bottom'		=> '1.4em'
				),
			'h1' => array(
				'title'				=> esc_html__('Heading 1', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '4.688rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '5.625rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '-1.6px',
				'margin-top'		=> '0.9583em',
				'margin-bottom'		=> '0.96em'
				),
			'h2' => array(
				'title'				=> esc_html__('Heading 2', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '4.063rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '5rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '-1.3px',
				'margin-top'		=> '1.7444em',
				'margin-bottom'		=> '1.26em'
				),
			'h3' => array(
				'title'				=> esc_html__('Heading 3', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '3.438rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '4.375rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '-1.1px',
				'margin-top'		=> '2.06em',
				'margin-bottom'		=> '1.1em'
				),
			'h4' => array(
				'title'				=> esc_html__('Heading 4', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '2.813rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '3.75rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '-1px',
				'margin-top'		=> '2.52em',
				'margin-bottom'		=> '0.87em'
				),
			'h5' => array(
				'title'				=> esc_html__('Heading 5', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '2.188rem',
				'font-weight'		=> '300',
				'font-style'		=> 'normal',
				'line-height'		=> '2.5rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '-0.7px',
				'margin-top'		=> '3.5em',
				'margin-bottom'		=> '1.24em'
				),
			'h6' => array(
				'title'				=> esc_html__('Heading 6', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '1.438rem',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.875rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'none',
				'letter-spacing'	=> '-0.5px',
				'margin-top'		=> '4.74em',
				'margin-bottom'		=> '1.4412em'
				),
			'logo' => array(
				'title'				=> esc_html__('Logo text', 'casamia'),
				'description'		=> esc_html__('Font settings of the text case of the logo', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '1.8em',
				'font-weight'		=> '400',
				'font-style'		=> 'normal',
				'line-height'		=> '1.25em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '1px'
				),
			'button' => array(
				'title'				=> esc_html__('Buttons', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '14px',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '1.5px'
				),
			'input' => array(
				'title'				=> esc_html__('Input fields', 'casamia'),
				'description'		=> esc_html__('Font settings of the input fields, dropdowns and textareas', 'casamia'),
				'font-family'		=> 'inherit',
				'font-size' 		=> '14px',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5rem',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '1px'
				),
			'info' => array(
				'title'				=> esc_html__('Post meta', 'casamia'),
				'description'		=> esc_html__('Font settings of the post meta: date, counters, share, etc.', 'casamia'),
				'font-family'		=> 'inherit',
				'font-size' 		=> '14px',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '0px',
				'margin-top'		=> '0.4em',
				'margin-bottom'		=> ''
				),
			'menu' => array(
				'title'				=> esc_html__('Main menu', 'casamia'),
				'description'		=> esc_html__('Font settings of the main menu items', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '14px',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '1.4px'
				),
			'submenu' => array(
				'title'				=> esc_html__('Dropdown menu', 'casamia'),
				'description'		=> esc_html__('Font settings of the dropdown menu items', 'casamia'),
				'font-family'		=> '"Montserrat",sans-serif',
				'font-size' 		=> '14px',
				'font-weight'		=> '500',
				'font-style'		=> 'normal',
				'line-height'		=> '1.5em',
				'text-decoration'	=> 'none',
				'text-transform'	=> 'uppercase',
				'letter-spacing'	=> '1.4px'
				)
		));


		// -----------------------------------------------------------------
		// -- Theme colors for customizer
		// -- Attention! Inner scheme must be last in the array below
		// -----------------------------------------------------------------
		casamia_storage_set('scheme_color_groups', array(
			'main'	=> array(
							'title'			=> esc_html__('Main', 'casamia'),
							'description'	=> esc_html__('Colors of the main content area', 'casamia')
							),
			'alter'	=> array(
							'title'			=> esc_html__('Alter', 'casamia'),
							'description'	=> esc_html__('Colors of the alternative blocks (sidebars, etc.)', 'casamia')
							),
			'extra'	=> array(
							'title'			=> esc_html__('Extra', 'casamia'),
							'description'	=> esc_html__('Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'casamia')
							),
			'inverse' => array(
							'title'			=> esc_html__('Inverse', 'casamia'),
							'description'	=> esc_html__('Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'casamia')
							),
			'input'	=> array(
							'title'			=> esc_html__('Input', 'casamia'),
							'description'	=> esc_html__('Colors of the form fields (text field, textarea, select, etc.)', 'casamia')
							),
			)
		);
		casamia_storage_set('scheme_color_names', array(
			'bg_color'	=> array(
							'title'			=> esc_html__('Background color', 'casamia'),
							'description'	=> esc_html__('Background color of this block in the normal state', 'casamia')
							),
			'bg_hover'	=> array(
							'title'			=> esc_html__('Background hover', 'casamia'),
							'description'	=> esc_html__('Background color of this block in the hovered state', 'casamia')
							),
			'bd_color'	=> array(
							'title'			=> esc_html__('Border color', 'casamia'),
							'description'	=> esc_html__('Border color of this block in the normal state', 'casamia')
							),
			'bd_hover'	=>  array(
							'title'			=> esc_html__('Border hover', 'casamia'),
							'description'	=> esc_html__('Border color of this block in the hovered state', 'casamia')
							),
			'text'		=> array(
							'title'			=> esc_html__('Text', 'casamia'),
							'description'	=> esc_html__('Color of the plain text inside this block', 'casamia')
							),
			'text_dark'	=> array(
							'title'			=> esc_html__('Text dark', 'casamia'),
							'description'	=> esc_html__('Color of the dark text (bold, header, etc.) inside this block', 'casamia')
							),
			'text_light'=> array(
							'title'			=> esc_html__('Text light', 'casamia'),
							'description'	=> esc_html__('Color of the light text (post meta, etc.) inside this block', 'casamia')
							),
			'text_link'	=> array(
							'title'			=> esc_html__('Link', 'casamia'),
							'description'	=> esc_html__('Color of the links inside this block', 'casamia')
							),
			'text_hover'=> array(
							'title'			=> esc_html__('Link hover', 'casamia'),
							'description'	=> esc_html__('Color of the hovered state of links inside this block', 'casamia')
							),
			'text_link2'=> array(
							'title'			=> esc_html__('Link 2', 'casamia'),
							'description'	=> esc_html__('Color of the accented texts (areas) inside this block', 'casamia')
							),
			'text_hover2'=> array(
							'title'			=> esc_html__('Link 2 hover', 'casamia'),
							'description'	=> esc_html__('Color of the hovered state of accented texts (areas) inside this block', 'casamia')
							),
			'text_link3'=> array(
							'title'			=> esc_html__('Link 3', 'casamia'),
							'description'	=> esc_html__('Color of the other accented texts (buttons) inside this block', 'casamia')
							),
			'text_hover3'=> array(
							'title'			=> esc_html__('Link 3 hover', 'casamia'),
							'description'	=> esc_html__('Color of the hovered state of other accented texts (buttons) inside this block', 'casamia')
							)
			)
		);
		casamia_storage_set('schemes', array(
		
			// Color scheme: 'default'
			'default' => array(
				'title'	 => esc_html__('Default', 'casamia'),
				'colors' => array(
					
					// Whole block border and background
					'bg_color'			=> '#ffffff',
					'bd_color'			=> '#e5e5e5',
		
					// Text and links colors
					'text'				=> '#767676',  //+
					'text_light'		=> '#b7b7b7',
					'text_dark'			=> '#1d2023',  //+
					'text_link'			=> '#ffa752',  //+
					'text_hover'		=> '#21bec5',  //+
					'text_link2'		=> '#80d572',
					'text_hover2'		=> '#8be77c',
					'text_link3'		=> '#ddb837',
					'text_hover3'		=> '#eec432',
		
					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'	=> '#f4f7f7',  //+
					'alter_bg_hover'	=> '#e6e8eb',
					'alter_bd_color'	=> '#e3e5e5',  //+
					'alter_bd_hover'	=> '#dadada',
					'alter_text'		=> '#333333',
					'alter_light'		=> '#b7b7b7',
					'alter_dark'		=> '#1d1d1d',
					'alter_link'		=> '#343739',  //+
					'alter_hover'		=> '#ffa752',  //+
					'alter_link2'		=> '#1db4de',  //+
					'alter_hover2'		=> '#42cab0',  //+
					'alter_link3'		=> '#fea759',  //+
					'alter_hover3'		=> '#edc156',  //+
		
					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'	=> '#f0f0f0',  //+
					'extra_bg_hover'	=> '#28272e',
					'extra_bd_color'	=> '#313131',
					'extra_bd_hover'	=> '#3d3d3d',
					'extra_text'		=> '#bfbfbf',
					'extra_light'		=> '#afafaf',
					'extra_dark'		=> '#ffffff',
					'extra_link'		=> '#767676',  //+
					'extra_hover'		=> '#ffa752',  //+
					'extra_link2'		=> '#80d572',
					'extra_hover2'		=> '#8be77c',
					'extra_link3'		=> '#ddb837',
					'extra_hover3'		=> '#eec432',
		
					// Input fields (form's fields and textarea)
					'input_bg_color'	=> '#efefef',  //+
					'input_bg_hover'	=> '#efefef',  //+
					'input_bd_color'	=> '#efefef',  //+
					'input_bd_hover'	=> '#ffa752',  //+
					'input_text'		=> '#b7b7b7',
					'input_light'		=> '#d0d0d0',
					'input_dark'		=> '#1d2023',  //+
					
					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color'	=> '#67bcc1',
					'inverse_bd_hover'	=> '#5aa4a9',
					'inverse_text'		=> '#1d1d1d',
					'inverse_light'		=> '#333333',
					'inverse_dark'		=> '#1d2023',  //+
					'inverse_link'		=> '#ffffff',
					'inverse_hover'		=> '#1d1d1d'
				)
			),
		
			// Color scheme: 'dark'
			'dark' => array(
				'title'  => esc_html__('Dark', 'casamia'),
				'colors' => array(
					
					// Whole block border and background
					'bg_color'			=> '#0e0d12',
					'bd_color'			=> '#1c1b1f',
		
					// Text and links colors
					'text'				=> '#767676',  //+
					'text_light'		=> '#5f5f5f',
					'text_dark'			=> '#ffffff',
					'text_link'			=> '#ffa752',  //+
					'text_hover'		=> '#21bec5',  //+
					'text_link2'		=> '#80d572',
					'text_hover2'		=> '#8be77c',
					'text_link3'		=> '#ddb837',
					'text_hover3'		=> '#eec432',

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'	=> '#1e1d22',
					'alter_bg_hover'	=> '#28272e',
					'alter_bd_color'	=> '#313131',
					'alter_bd_hover'	=> '#3d3d3d',
					'alter_text'		=> '#a6a6a6',
					'alter_light'		=> '#5f5f5f',
					'alter_dark'		=> '#ffffff',
					'alter_link'		=> '#343739',  //+
					'alter_hover'		=> '#ffffff',  //+
					'alter_link2'		=> '#1db4de',  //+
					'alter_hover2'		=> '#42cab0',  //+
					'alter_link3'		=> '#fea759',  //+
					'alter_hover3'		=> '#edc156',  //+

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'	=> '#0e0d12',
					'extra_bg_hover'	=> '#28272e',
					'extra_bd_color'	=> '#313131',
					'extra_bd_hover'	=> '#3d3d3d',
					'extra_text'		=> '#a6a6a6',
					'extra_light'		=> '#5f5f5f',
					'extra_dark'		=> '#ffffff',
					'extra_link'		=> '#ffffff',  //+
					'extra_hover'		=> '#fe7259',
					'extra_link2'		=> '#80d572',
					'extra_hover2'		=> '#8be77c',
					'extra_link3'		=> '#ddb837',
					'extra_hover3'		=> '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'	=> '#343739',  //+
					'input_bg_hover'	=> '#343739',  //+
					'input_bd_color'	=> '#343739',  //+
					'input_bd_hover'	=> '#353535',
					'input_text'		=> '#b7b7b7',
					'input_light'		=> '#5f5f5f',
					'input_dark'		=> '#ffa752',  //+
					
					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color'	=> '#e36650',
					'inverse_bd_hover'	=> '#cb5b47',
					'inverse_text'		=> '#1d1d1d',
					'inverse_light'		=> '#5f5f5f',
					'inverse_dark'		=> '#000000',
					'inverse_link'		=> '#ffffff',
					'inverse_hover'		=> '#1d1d1d'
				)
			)
		
		));
		
		// Simple schemes substitution
		casamia_storage_set('schemes_simple', array(
			// Main color	// Slave elements and it's darkness koef.
			'text_link'		=> array('alter_hover' => 1,	'extra_link' => 1, 'inverse_bd_color' => 0.85, 'inverse_bd_hover' => 0.7),
			'text_hover'	=> array('alter_link' => 1,		'extra_hover' => 1),
			'text_link2'	=> array('alter_hover2' => 1,	'extra_link2' => 1),
			'text_hover2'	=> array('alter_link2' => 1,	'extra_hover2' => 1),
			'text_link3'	=> array('alter_hover3' => 1,	'extra_link3' => 1),
			'text_hover3'	=> array('alter_link3' => 1,	'extra_hover3' => 1)
		));
	}
}

			
// Additional (calculated) theme-specific colors
// Attention! Don't forget setup custom colors also in the theme.customizer.color-scheme.js
if (!function_exists('casamia_customizer_add_theme_colors')) {
	function casamia_customizer_add_theme_colors($colors) {
		if (substr($colors['text'], 0, 1) == '#') {
			$colors['bg_color_0']  = casamia_hex2rgba( $colors['bg_color'], 0 );
			$colors['bg_color_02']  = casamia_hex2rgba( $colors['bg_color'], 0.4 );
			$colors['bg_color_03']  = casamia_hex2rgba( $colors['bg_color'], 0.2 );
			$colors['bg_color_07']  = casamia_hex2rgba( $colors['bg_color'], 0.7 );
			$colors['bg_color_08']  = casamia_hex2rgba( $colors['bg_color'], 0.8 );
			$colors['bg_color_09']  = casamia_hex2rgba( $colors['bg_color'], 0.9 );
			$colors['alter_bg_color_07']  = casamia_hex2rgba( $colors['alter_bg_color'], 0.7 );
			$colors['alter_bg_color_04']  = casamia_hex2rgba( $colors['alter_bg_color'], 0.4 );
			$colors['alter_bg_color_02']  = casamia_hex2rgba( $colors['alter_bg_color'], 0.2 );
			$colors['alter_bd_color_02']  = casamia_hex2rgba( $colors['alter_bd_color'], 0.2 );
			$colors['extra_bg_color_07']  = casamia_hex2rgba( $colors['extra_bg_color'], 0.7 );
			$colors['text_dark_07']  = casamia_hex2rgba( $colors['text_dark'], 0.7 );
			$colors['text_dark_01']  = casamia_hex2rgba( $colors['text_dark'], 0.1 );
			$colors['text_dark_02']  = casamia_hex2rgba( $colors['text_dark'], 0.2 );
			$colors['text_dark_09']  = casamia_hex2rgba( $colors['text_dark'], 0.9 );
			$colors['text_link_02']  = casamia_hex2rgba( $colors['text_link'], 0.2 );
			$colors['text_link_07']  = casamia_hex2rgba( $colors['text_link'], 0.7 );
			$colors['alter_hover_07']  = casamia_hex2rgba( $colors['alter_hover'], 0.7 );
			$colors['inverse_link_02']  = casamia_hex2rgba( $colors['inverse_link'], 0.2 );
			$colors['text_link_blend'] = casamia_hsb2hex(casamia_hex2hsb( $colors['text_link'], 2, -5, 5 ));
			$colors['alter_link_blend'] = casamia_hsb2hex(casamia_hex2hsb( $colors['alter_link'], 2, -5, 5 ));
		} else {
			$colors['bg_color_0'] = '{{ data.bg_color_0 }}';
			$colors['bg_color_02'] = '{{ data.bg_color_02 }}';
			$colors['bg_color_03'] = '{{ data.bg_color_03 }}';
			$colors['bg_color_07'] = '{{ data.bg_color_07 }}';
			$colors['bg_color_08'] = '{{ data.bg_color_08 }}';
			$colors['bg_color_09'] = '{{ data.bg_color_09 }}';
			$colors['alter_bg_color_07'] = '{{ data.alter_bg_color_07 }}';
			$colors['alter_bg_color_04'] = '{{ data.alter_bg_color_04 }}';
			$colors['alter_bg_color_02'] = '{{ data.alter_bg_color_02 }}';
			$colors['alter_bd_color_02'] = '{{ data.alter_bd_color_02 }}';
			$colors['extra_bg_color_07'] = '{{ data.extra_bg_color_07 }}';
			$colors['text_dark_07'] = '{{ data.text_dark_07 }}';
			$colors['text_dark_01'] = '{{ data.text_dark_01 }}';
			$colors['text_dark_02'] = '{{ data.text_dark_02 }}';
			$colors['text_dark_09'] = '{{ data.text_dark_09 }}';
			$colors['text_link_02'] = '{{ data.text_link_02 }}';
			$colors['text_link_07'] = '{{ data.text_link_07 }}';
			$colors['alter_hover_07'] = '{{ data.alter_hover_07 }}';
			$colors['inverse_link_02'] = '{{ data.inverse_link_02 }}';
			$colors['text_link_blend'] = '{{ data.text_link_blend }}';
			$colors['alter_link_blend'] = '{{ data.alter_link_blend }}';
		}
		return $colors;
	}
}


			
// Additional theme-specific fonts rules
// Attention! Don't forget setup fonts rules also in the theme.customizer.color-scheme.js
if (!function_exists('casamia_customizer_add_theme_fonts')) {
	function casamia_customizer_add_theme_fonts($fonts) {
		$rez = array();	
		foreach ($fonts as $tag => $font) {
			if (substr($font['font-family'], 0, 2) != '{{') {
				$rez[$tag.'_font-family'] 		= !empty($font['font-family']) && !casamia_is_inherit($font['font-family'])
														? 'font-family:' . trim($font['font-family']) . ';' 
														: '';
				$rez[$tag.'_font-size'] 		= !empty($font['font-size']) && !casamia_is_inherit($font['font-size'])
														? 'font-size:' . casamia_prepare_css_value($font['font-size']) . ";"
														: '';
				$rez[$tag.'_line-height'] 		= !empty($font['line-height']) && !casamia_is_inherit($font['line-height'])
														? 'line-height:' . trim($font['line-height']) . ";"
														: '';
				$rez[$tag.'_font-weight'] 		= !empty($font['font-weight']) && !casamia_is_inherit($font['font-weight'])
														? 'font-weight:' . trim($font['font-weight']) . ";"
														: '';
				$rez[$tag.'_font-style'] 		= !empty($font['font-style']) && !casamia_is_inherit($font['font-style'])
														? 'font-style:' . trim($font['font-style']) . ";"
														: '';
				$rez[$tag.'_text-decoration'] 	= !empty($font['text-decoration']) && !casamia_is_inherit($font['text-decoration'])
														? 'text-decoration:' . trim($font['text-decoration']) . ";"
														: '';
				$rez[$tag.'_text-transform'] 	= !empty($font['text-transform']) && !casamia_is_inherit($font['text-transform'])
														? 'text-transform:' . trim($font['text-transform']) . ";"
														: '';
				$rez[$tag.'_letter-spacing'] 	= !empty($font['letter-spacing']) && !casamia_is_inherit($font['letter-spacing'])
														? 'letter-spacing:' . trim($font['letter-spacing']) . ";"
														: '';
				$rez[$tag.'_margin-top'] 		= !empty($font['margin-top']) && !casamia_is_inherit($font['margin-top'])
														? 'margin-top:' . casamia_prepare_css_value($font['margin-top']) . ";"
														: '';
				$rez[$tag.'_margin-bottom'] 	= !empty($font['margin-bottom']) && !casamia_is_inherit($font['margin-bottom'])
														? 'margin-bottom:' . casamia_prepare_css_value($font['margin-bottom']) . ";"
														: '';
			} else {
				$rez[$tag.'_font-family']		= '{{ data["'.$tag.'_font-family"] }}';
				$rez[$tag.'_font-size']			= '{{ data["'.$tag.'_font-size"] }}';
				$rez[$tag.'_line-height']		= '{{ data["'.$tag.'_line-height"] }}';
				$rez[$tag.'_font-weight']		= '{{ data["'.$tag.'_font-weight"] }}';
				$rez[$tag.'_font-style']		= '{{ data["'.$tag.'_font-style"] }}';
				$rez[$tag.'_text-decoration']	= '{{ data["'.$tag.'_text-decoration"] }}';
				$rez[$tag.'_text-transform']	= '{{ data["'.$tag.'_text-transform"] }}';
				$rez[$tag.'_letter-spacing']	= '{{ data["'.$tag.'_letter-spacing"] }}';
				$rez[$tag.'_margin-top']		= '{{ data["'.$tag.'_margin-top"] }}';
				$rez[$tag.'_margin-bottom']		= '{{ data["'.$tag.'_margin-bottom"] }}';
			}
		}
		return $rez;
	}
}




//-------------------------------------------------------
//-- Thumb sizes
//-------------------------------------------------------

if ( !function_exists('casamia_customizer_theme_setup') ) {
	add_action( 'after_setup_theme', 'casamia_customizer_theme_setup' );
	function casamia_customizer_theme_setup() {

		// Enable support for Post Thumbnails
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size(370, 0, false);
		
		// Add thumb sizes
		// ATTENTION! If you change list below - check filter's names in the 'trx_addons_filter_get_thumb_size' hook
		$thumb_sizes = apply_filters('casamia_filter_add_thumb_sizes', array(
			'casamia-thumb-huge'		=> array(1170, 658, true),
			'casamia-thumb-big' 		=> array( 1540, 762, true),
			'casamia-thumb-med' 		=> array( 740, 510, true),
			'casamia-thumb-tiny' 		=> array(  90,  90, true),
			'casamia-thumb-related' 	=> array(  738,  734, true),
			'casamia-thumb-services' 	=> array(  740,  630, true),
			'casamia-thumb-properties' 	=> array(  1140,  588, true),
			'casamia-thumb-team' 	    => array(  740,  830, true),
			'casamia-thumb-testimonials' 	    => array(  212,  212, true),
			'casamia-thumb-services-list' 	    => array(  456,  636, true),
			'casamia-thumb-masonry-big' => array( 760,   0, false),		// Only downscale, not crop
			'casamia-thumb-masonry'		=> array( 370,   0, false),		// Only downscale, not crop
			)
		);
		$mult = casamia_get_theme_option('retina_ready', 1);
		if ($mult > 1) $GLOBALS['content_width'] = apply_filters( 'casamia_filter_content_width', 1170*$mult);
		foreach ($thumb_sizes as $k=>$v) {
			// Add Original dimensions
			add_image_size( $k, $v[0], $v[1], $v[2]);
			// Add Retina dimensions
			if ($mult > 1) add_image_size( $k.'-@retina', $v[0]*$mult, $v[1]*$mult, $v[2]);
		}

	}
}

if ( !function_exists('casamia_customizer_image_sizes') ) {
	add_filter( 'image_size_names_choose', 'casamia_customizer_image_sizes' );
	function casamia_customizer_image_sizes( $sizes ) {
		$thumb_sizes = apply_filters('casamia_filter_add_thumb_sizes', array(
			'casamia-thumb-huge'		=> esc_html__( 'Huge image', 'casamia' ),
			'casamia-thumb-big'			=> esc_html__( 'Large image', 'casamia' ),
			'casamia-thumb-med'			=> esc_html__( 'Medium image', 'casamia' ),
			'casamia-thumb-tiny'		=> esc_html__( 'Small square avatar', 'casamia' ),
			'casamia-thumb-masonry-big'	=> esc_html__( 'Masonry Large (scaled)', 'casamia' ),
			'casamia-thumb-masonry'		=> esc_html__( 'Masonry (scaled)', 'casamia' ),
			)
		);
		$mult = casamia_get_theme_option('retina_ready', 1);
		foreach($thumb_sizes as $k=>$v) {
			$sizes[$k] = $v;
			if ($mult > 1) $sizes[$k.'-@retina'] = $v.' '.esc_html__('@2x', 'casamia' );
		}
		return $sizes;
	}
}

// Remove some thumb-sizes from the ThemeREX Addons list
if ( !function_exists( 'casamia_customizer_trx_addons_add_thumb_sizes' ) ) {
	add_filter( 'trx_addons_filter_add_thumb_sizes', 'casamia_customizer_trx_addons_add_thumb_sizes');
	function casamia_customizer_trx_addons_add_thumb_sizes($list=array()) {
		if (is_array($list)) {
			foreach ($list as $k=>$v) {
				if (in_array($k, array(
								'trx_addons-thumb-huge',
								'trx_addons-thumb-big',
								'trx_addons-thumb-medium',
								'trx_addons-thumb-tiny',
								'trx_addons-thumb-masonry-big',
								'trx_addons-thumb-masonry',
								)
							)
						) unset($list[$k]);
			}
		}
		return $list;
	}
}

// and replace removed styles with theme-specific thumb size
if ( !function_exists( 'casamia_customizer_trx_addons_get_thumb_size' ) ) {
	add_filter( 'trx_addons_filter_get_thumb_size', 'casamia_customizer_trx_addons_get_thumb_size');
	function casamia_customizer_trx_addons_get_thumb_size($thumb_size='') {
		return str_replace(array(
							'trx_addons-thumb-huge',
							'trx_addons-thumb-huge-@retina',
							'trx_addons-thumb-big',
							'trx_addons-thumb-big-@retina',
							'trx_addons-thumb-medium',
							'trx_addons-thumb-medium-@retina',
							'trx_addons-thumb-tiny',
							'trx_addons-thumb-tiny-@retina',
							'trx_addons-thumb-related',
							'trx_addons-thumb-related-@retina',
							'trx_addons-thumb-services',
							'trx_addons-thumb-services-@retina',
							'trx_addons-thumb-properties',
							'trx_addons-thumb-properties-@retina',
							'trx_addons-thumb-team',
							'trx_addons-thumb-team-@retina',
							'trx_addons-thumb-testimonials',
							'trx_addons-thumb-testimonials-@retina',
							'trx_addons-thumb-services-list',
							'trx_addons-thumb-services-list-@retina',
							'trx_addons-thumb-masonry-big',
							'trx_addons-thumb-masonry-big-@retina',
							'trx_addons-thumb-masonry',
							'trx_addons-thumb-masonry-@retina',
							),
							array(
							'casamia-thumb-huge',
							'casamia-thumb-huge-@retina',
							'casamia-thumb-big',
							'casamia-thumb-big-@retina',
							'casamia-thumb-med',
							'casamia-thumb-med-@retina',
							'casamia-thumb-tiny',
							'casamia-thumb-tiny-@retina',
							'casamia-thumb-related',
							'casamia-thumb-related-@retina',
							'casamia-thumb-services',
							'casamia-thumb-services-@retina',
							'casamia-thumb-properties',
							'casamia-thumb-properties-@retina',
							'casamia-thumb-team',
							'casamia-thumb-team-@retina',
							'casamia-thumb-testimonials',
							'casamia-thumb-testimonials-@retina',
							'casamia-thumb-services-list',
							'casamia-thumb-services-list-@retina',
							'casamia-thumb-masonry-big',
							'casamia-thumb-masonry-big-@retina',
							'casamia-thumb-masonry',
							'casamia-thumb-masonry-@retina',
							),
							$thumb_size);
	}
}




//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( !function_exists( 'casamia_importer_set_options' ) ) {
	add_filter( 'trx_addons_filter_importer_options', 'casamia_importer_set_options', 9 );
	function casamia_importer_set_options($options=array()) {
		if (is_array($options)) {
			// Save or not installer's messages to the log-file
			$options['debug'] = false;
			// Prepare demo data
			$options['demo_url'] = esc_url(casamia_get_protocol() . '://demofiles.ancorathemes.com/casamia/');
			// Required plugins
			$options['required_plugins'] = array_keys(casamia_storage_get('required_plugins'));
			// Default demo
			$options['files']['default']['title'] = esc_html__('CASAMIA Demo', 'casamia');
			$options['files']['default']['domain_dev'] = esc_url(casamia_get_protocol().'://casamia.dv.ancorathemes.com');		// Developers domain
			$options['files']['default']['domain_demo']= esc_url('http://casamia.ancorathemes.com');		// Demo-site domain
		}
		return $options;
	}
}




// -----------------------------------------------------------------
// -- Theme options for customizer
// -----------------------------------------------------------------
if (!function_exists('casamia_create_theme_options')) {

	function casamia_create_theme_options() {

		// Message about options override. 
		// Attention! Not need esc_html() here, because this message put in wp_kses_data() below
		$msg_override = __('<b>Attention!</b> Some of these options can be overridden in the following sections (Blog, Plugins settings, etc.) or in the settings of individual pages', 'casamia');

		casamia_storage_set('options', array(
		
			// 'Logo & Site Identity'
			'title_tagline' => array(
				"title" => esc_html__('Logo & Site Identity', 'casamia'),
				"desc" => '',
				"priority" => 10,
				"type" => "section"
				),
			'logo_info' => array(
				"title" => esc_html__('Logo in the header', 'casamia'),
				"desc" => '',
				"priority" => 20,
				"type" => "info",
				),
			'logo_text' => array(
				"title" => esc_html__('Use Site Name as Logo', 'casamia'),
				"desc" => wp_kses_data( __('Use the site title and tagline as a text logo if no image is selected', 'casamia') ),
				"class" => "casamia_column-1_2 casamia_new_row",
				"priority" => 30,
				"std" => 1,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),
			'logo_retina_enabled' => array(
				"title" => esc_html__('Allow retina display logo', 'casamia'),
				"desc" => wp_kses_data( __('Show fields to select logo images for Retina display', 'casamia') ),
				"class" => "casamia_column-1_2",
				"refresh" => false,
				"std" => 0,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),
			'logo' => array(
				"title" => esc_html__('Logo', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload site logo', 'casamia') ),
				"class" => "casamia_column-1_2 casamia_new_row",
				"std" => '',
				"type" => "image"
				),
			'logo_retina' => array(
				"title" => esc_html__('Logo for Retina', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'casamia') ),
				"class" => "casamia_column-1_2",
				"dependency" => array(
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "image"
				),
			'logo_mobile' => array(
				"title" => esc_html__('Logo mobile', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it in the mobile menu', 'casamia') ),
				"class" => "casamia_column-1_2 casamia_new_row",
				"std" => '',
				"type" => "image"
				),
			'logo_mobile_retina' => array(
				"title" => esc_html__('Logo mobile for Retina', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'casamia') ),
				"class" => "casamia_column-1_2",
				"dependency" => array(
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "image"
				),
			'logo_side' => array(
				"title" => esc_html__('Logo side', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu', 'casamia') ),
				"class" => "casamia_column-1_2 casamia_new_row",
				"std" => '',
				"type" => "image"
				),
			'logo_side_retina' => array(
				"title" => esc_html__('Logo side for Retina', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu on Retina displays (if empty - use default logo from the field above)', 'casamia') ),
				"class" => "casamia_column-1_2",
				"dependency" => array(
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "image"
				),
			
		
		
			// 'General settings'
			'general' => array(
				"title" => esc_html__('General Settings', 'casamia'),
				"desc" => wp_kses_data( __('Settings for the entire site', 'casamia') )
							. '<br>'
							. wp_kses_data( $msg_override ),
				"priority" => 20,
				"type" => "section",
				),

			'general_layout_info' => array(
				"title" => esc_html__('Layout', 'casamia'),
				"desc" => '',
				"type" => "info",
				),
			'body_style' => array(
				"title" => esc_html__('Body style', 'casamia'),
				"desc" => wp_kses_data( __('Select width of the body content', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'casamia')
				),
				"refresh" => false,
				"std" => 'wide',
				"options" => array(
					'boxed'		=> esc_html__('Boxed',		'casamia'),
					'wide'		=> esc_html__('Wide',		'casamia'),
					'fullwide'	=> esc_html__('Fullwide',	'casamia'),
					'fullscreen'=> esc_html__('Fullscreen',	'casamia')
				),
				"type" => "select"
				),
			'boxed_bg_image' => array(
				"title" => esc_html__('Boxed bg image', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload image, used as background in the boxed body', 'casamia') ),
				"dependency" => array(
					'body_style' => array('boxed')
				),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'casamia')
				),
				"std" => '',
				"hidden" => true,
				"type" => "image"
				),
			'remove_margins' => array(
				"title" => esc_html__('Remove margins', 'casamia'),
				"desc" => wp_kses_data( __('Remove margins above and below the content area', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'casamia')
				),
				"refresh" => false,
				"std" => 0,
				"type" => "checkbox"
				),

			'general_sidebar_info' => array(
				"title" => esc_html__('Sidebar', 'casamia'),
				"desc" => '',
				"type" => "info",
				),
			'sidebar_position' => array(
				"title" => esc_html__('Sidebar position', 'casamia'),
				"desc" => wp_kses_data( __('Select position to show sidebar', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'casamia')
				),
				"std" => 'right',
				"options" => array(),
				"type" => "switch"
				),
			'sidebar_widgets' => array(
				"title" => esc_html__('Sidebar widgets', 'casamia'),
				"desc" => wp_kses_data( __('Select default widgets to show in the sidebar', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'casamia')
				),
				"dependency" => array(
					'sidebar_position' => array('left', 'right')
				),
				"std" => 'sidebar_widgets',
				"options" => array(),
				"type" => "select"
				),
			'expand_content' => array(
				"title" => esc_html__('Expand content', 'casamia'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'casamia') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),


			'general_widgets_info' => array(
				"title" => esc_html__('Additional widgets', 'casamia'),
				"desc" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "info",
				),
			'widgets_above_page' => array(
				"title" => esc_html__('Widgets at the top of the page', 'casamia'),
				"desc" => wp_kses_data( __('Select widgets to show at the top of the page (above content and sidebar)', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'casamia')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
				),
			'widgets_above_content' => array(
				"title" => esc_html__('Widgets above the content', 'casamia'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'casamia')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
				),
			'widgets_below_content' => array(
				"title" => esc_html__('Widgets below the content', 'casamia'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'casamia')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
				),
			'widgets_below_page' => array(
				"title" => esc_html__('Widgets at the bottom of the page', 'casamia'),
				"desc" => wp_kses_data( __('Select widgets to show at the bottom of the page (below content and sidebar)', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'casamia')
				),
				"std" => 'hide',
				"options" => array(),
				"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
				),

			'general_effects_info' => array(
				"title" => esc_html__('Design & Effects', 'casamia'),
				"desc" => '',
				"type" => "info",
				),
			'border_radius' => array(
				"title" => esc_html__('Border radius', 'casamia'),
				"desc" => wp_kses_data( __('Specify the border radius of the form fields and buttons in pixels or other valid CSS units', 'casamia') ),
				"std" => 0,
				"type" => "text"
				),

			'general_misc_info' => array(
				"title" => esc_html__('Miscellaneous', 'casamia'),
				"desc" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "info",
				),
			'seo_snippets' => array(
				"title" => esc_html__('SEO snippets', 'casamia'),
				"desc" => wp_kses_data( __('Add structured data markup to the single posts and pages', 'casamia') ),
				"std" => 0,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),

            'privacy_text' => array(
                "title" => esc_html__("Text with Privacy Policy link", 'casamia'),
                "desc"  => wp_kses_data( __("Specify text with Privacy Policy link for the checkbox 'I agree ...'", 'casamia') ),
                "std"   => wp_kses( __( 'I agree that my submitted data is being collected and stored.', 'casamia'), 'casamia_kses_content' ),
                "type"  => "text"
            ),
		
		
			// 'Header'
			'header' => array(
				"title" => esc_html__('Header', 'casamia'),
				"desc" => wp_kses_data( $msg_override ),
				"priority" => 30,
				"type" => "section"
				),

			'header_style_info' => array(
				"title" => esc_html__('Header style', 'casamia'),
				"desc" => '',
				"type" => "info"
				),
			'header_style' => array(
				"title" => esc_html__('Header style', 'casamia'),
				"desc" => wp_kses_data( __('Select style to display the site header', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"std" => 'header-default',
				"options" => array(),
				"type" => "select"
				),
			'header_position' => array(
				"title" => esc_html__('Header position', 'casamia'),
				"desc" => wp_kses_data( __('Select position to display the site header', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"std" => 'default',
				"options" => array(),
				"type" => CASAMIA_THEME_FREE ? "hidden" : "switch"
				),
			'header_fullheight' => array(
				"title" => esc_html__('Header fullheight', 'casamia'),
				"desc" => wp_kses_data( __("Enlarge header area to fill whole screen. Used only if header have a background image", 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"std" => 0,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),
			'header_wide' => array(
				"title" => esc_html__('Header fullwide', 'casamia'),
				"desc" => wp_kses_data( __('Do you want to stretch the header widgets area to the entire window width?', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"dependency" => array(
					'header_style' => array('header-default')
				),
				"std" => 1,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),

			'header_widgets_info' => array(
				"title" => esc_html__('Header widgets', 'casamia'),
				"desc" => wp_kses_data( __('Here you can place a widget slider, advertising banners, etc.', 'casamia') ),
				"type" => "info"
				),
			'header_widgets' => array(
				"title" => esc_html__('Header widgets', 'casamia'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on each page', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia'),
					"desc" => wp_kses_data( __('Select set of widgets to show in the header on this page', 'casamia') ),
				),
				"std" => 'hide',
				"options" => array(),
				"type" => "select"
				),
			'header_columns' => array(
				"title" => esc_html__('Header columns', 'casamia'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the Header. If 0 - autodetect by the widgets count', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"dependency" => array(
					'header_style' => array('header-default'),
					'header_widgets' => array('^hide')
				),
				"std" => 0,
				"options" => casamia_get_list_range(0,6),
				"type" => "select"
				),

			'menu_info' => array(
				"title" => esc_html__('Main menu', 'casamia'),
				"desc" => wp_kses_data( __('Select main menu style, position, color scheme and other parameters', 'casamia') ),
				"type" => CASAMIA_THEME_FREE ? "hidden" : "info"
				),
			'menu_style' => array(
				"title" => esc_html__('Menu position', 'casamia'),
				"desc" => wp_kses_data( __('Select position of the main menu', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"std" => 'top',
				"options" => array(
					'top'	=> esc_html__('Top',	'casamia'),
					'left'	=> esc_html__('Left',	'casamia'),
					'right'	=> esc_html__('Right',	'casamia')
				),
				"type" => CASAMIA_THEME_FREE ? "hidden" : "switch"
				),
			'menu_side_stretch' => array(
				"title" => esc_html__('Stretch sidemenu', 'casamia'),
				"desc" => wp_kses_data( __('Stretch sidemenu to window height (if menu items number >= 5)', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 0,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),
			'menu_side_icons' => array(
				"title" => esc_html__('Iconed sidemenu', 'casamia'),
				"desc" => wp_kses_data( __('Get icons from anchors and display it in the sidemenu or mark sidemenu items with simple dots', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Header', 'casamia')
				),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),
			'menu_mobile_fullscreen' => array(
				"title" => esc_html__('Mobile menu fullscreen', 'casamia'),
				"desc" => wp_kses_data( __('Display mobile and side menus on full screen (if checked) or slide narrow menu from the left or from the right side (if not checked)', 'casamia') ),
				"std" => 1,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),

			'header_image_info' => array(
				"title" => esc_html__('Header image', 'casamia'),
				"desc" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "info"
				),
			'header_image_override' => array(
				"title" => esc_html__('Header image override', 'casamia'),
				"desc" => wp_kses_data( __("Allow override the header image with the page's/post's/product's/etc. featured image", 'casamia') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'casamia')
				),
				"std" => 0,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
				),


		
			// 'Footer'
			'footer' => array(
				"title" => esc_html__('Footer', 'casamia'),
				"desc" => wp_kses_data( __('Select set of widgets and columns number in the site footer', 'casamia') )
							. '<br>'
							. wp_kses_data( $msg_override ),
				"priority" => 50,
				"type" => "section"
				),
			'footer_style' => array(
				"title" => esc_html__('Footer style', 'casamia'),
				"desc" => wp_kses_data( __('Select style to display the site footer', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'casamia')
				),
				"std" => 'footer-default',
				"options" => array(),
				"type" => "select"
				),
			'footer_widgets' => array(
				"title" => esc_html__('Footer widgets', 'casamia'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the footer', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'casamia')
				),
				"dependency" => array(
					'footer_style' => array('footer-default')
				),
				"std" => 'footer_widgets',
				"options" => array(),
				"type" => "select"
				),
			'footer_columns' => array(
				"title" => esc_html__('Footer columns', 'casamia'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'casamia')
				),
				"dependency" => array(
					'footer_style' => array('footer-default'),
					'footer_widgets' => array('^hide')
				),
				"std" => 3,
				"options" => casamia_get_list_range(0,6),
				"type" => "select"
				),
			'footer_wide' => array(
				"title" => esc_html__('Footer fullwide', 'casamia'),
				"desc" => wp_kses_data( __('Do you want to stretch the footer to the entire window width?', 'casamia') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'casamia')
				),
				"dependency" => array(
					'footer_style' => array('footer-default')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_in_footer' => array(
				"title" => esc_html__('Show logo', 'casamia'),
				"desc" => wp_kses_data( __('Show logo in the footer', 'casamia') ),
				'refresh' => false,
				"dependency" => array(
					'footer_style' => array('footer-default')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_footer' => array(
				"title" => esc_html__('Logo for footer', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it in the footer', 'casamia') ),
				"dependency" => array(
					'footer_style' => array('footer-default'),
					'logo_in_footer' => array(1)
				),
				"std" => '',
				"type" => "image"
				),
			'logo_footer_retina' => array(
				"title" => esc_html__('Logo for footer (Retina)', 'casamia'),
				"desc" => wp_kses_data( __('Select or upload logo for the footer area used on Retina displays (if empty - use default logo from the field above)', 'casamia') ),
				"dependency" => array(
					'footer_style' => array('footer-default'),
					'logo_in_footer' => array(1),
					'logo_retina_enabled' => array(1)
				),
				"std" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "image"
				),
			'socials_in_footer' => array(
				"title" => esc_html__('Show social icons', 'casamia'),
				"desc" => wp_kses_data( __('Show social icons in the footer (under logo or footer widgets)', 'casamia') ),
				"dependency" => array(
					'footer_style' => array('footer-default')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'copyright' => array(
				"title" => esc_html__('Copyright', 'casamia'),
				"desc" => wp_kses_data( __('Copyright text in the footer. Use {Y} to insert current year and press "Enter" to create a new line', 'casamia') ),
				"std" => esc_html__('AncoraThemes &copy; {Y}. All rights reserved.', 'casamia'),
				"dependency" => array(
					'footer_style' => array('footer-default')
				),
				"refresh" => false,
				"type" => "textarea"
				),
			
		
		
			// 'Blog'
			'blog' => array(
				"title" => esc_html__('Blog', 'casamia'),
				"desc" => wp_kses_data( __('Options of the the blog archive', 'casamia') ),
				"priority" => 70,
				"type" => "panel",
				),
		
				// Blog - Posts page
				'blog_general' => array(
					"title" => esc_html__('Posts page', 'casamia'),
					"desc" => wp_kses_data( __('Style and components of the blog archive', 'casamia') ),
					"type" => "section",
					),
				'blog_general_info' => array(
					"title" => esc_html__('General settings', 'casamia'),
					"desc" => '',
					"type" => "info",
					),
				'blog_style' => array(
					"title" => esc_html__('Blog style', 'casamia'),
					"desc" => '',
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"std" => 'excerpt',
					"options" => array(),
					"type" => "select"
					),
				'first_post_large' => array(
					"title" => esc_html__('First post large', 'casamia'),
					"desc" => wp_kses_data( __('Make your first post stand out by making it bigger', 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
						'blog_style' => array('classic', 'masonry')
					),
					"std" => 0,
					"type" => "checkbox"
					),
				"blog_content" => array( 
					"title" => esc_html__('Posts content', 'casamia'),
					"desc" => wp_kses_data( __("Display either post excerpts or the full post content", 'casamia') ),
					"std" => "excerpt",
					"dependency" => array(
						'blog_style' => array('excerpt')
					),
					"options" => array(
						'excerpt'	=> esc_html__('Excerpt',	'casamia'),
						'fullpost'	=> esc_html__('Full post',	'casamia')
					),
					"type" => "switch"
					),
				'excerpt_length' => array(
					"title" => esc_html__('Excerpt length', 'casamia'),
					"desc" => wp_kses_data( __("Length (in words) to generate excerpt from the post content. Attention! If the post excerpt is explicitly specified - it appears unchanged", 'casamia') ),
					"dependency" => array(
						'blog_style' => array('excerpt'),
						'blog_content' => array('excerpt')
					),
					"std" => 40,
					"type" => "text"
					),
				'blog_columns' => array(
					"title" => esc_html__('Blog columns', 'casamia'),
					"desc" => wp_kses_data( __('How many columns should be used in the blog archive (from 2 to 4)?', 'casamia') ),
					"std" => 2,
					"options" => casamia_get_list_range(2,4),
					"type" => "hidden"
					),
				'post_type' => array(
					"title" => esc_html__('Post type', 'casamia'),
					"desc" => wp_kses_data( __('Select post type to show in the blog archive', 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"linked" => 'parent_cat',
					"refresh" => false,
					"hidden" => true,
					"std" => 'post',
					"options" => array(),
					"type" => "select"
					),
				'parent_cat' => array(
					"title" => esc_html__('Category to show', 'casamia'),
					"desc" => wp_kses_data( __('Select category to show in the blog archive', 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"refresh" => false,
					"hidden" => true,
					"std" => '0',
					"options" => array(),
					"type" => "select"
					),
				'posts_per_page' => array(
					"title" => esc_html__('Posts per page', 'casamia'),
					"desc" => wp_kses_data( __('How many posts will be displayed on this page', 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"hidden" => true,
					"std" => '',
					"type" => "text"
					),
				"blog_pagination" => array( 
					"title" => esc_html__('Pagination style', 'casamia'),
					"desc" => wp_kses_data( __('Show Older/Newest posts or Page numbers below the posts list', 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"std" => "links",
					"options" => array(
						'pages'	=> esc_html__("Page numbers", 'casamia'),
						'links'	=> esc_html__("Older/Newest", 'casamia'),
						'more'	=> esc_html__("Load more", 'casamia'),
						'infinite' => esc_html__("Infinite scroll", 'casamia')
					),
					"type" => "select"
					),
				'show_filters' => array(
					"title" => esc_html__('Show filters', 'casamia'),
					"desc" => wp_kses_data( __('Show categories as tabs to filter posts', 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
						'blog_style' => array('portfolio', 'gallery')
					),
					"hidden" => true,
					"std" => 0,
					"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
					),
	
				'blog_sidebar_info' => array(
					"title" => esc_html__('Sidebar', 'casamia'),
					"desc" => '',
					"type" => "info",
					),
				'sidebar_position_blog' => array(
					"title" => esc_html__('Sidebar position', 'casamia'),
					"desc" => wp_kses_data( __('Select position to show sidebar', 'casamia') ),
					"std" => 'right',
					"options" => array(),
					"type" => "switch"
					),
				'sidebar_widgets_blog' => array(
					"title" => esc_html__('Sidebar widgets', 'casamia'),
					"desc" => wp_kses_data( __('Select default widgets to show in the sidebar', 'casamia') ),
					"dependency" => array(
						'sidebar_position_blog' => array('left', 'right')
					),
					"std" => 'sidebar_widgets',
					"options" => array(),
					"type" => "select"
					),
				'expand_content_blog' => array(
					"title" => esc_html__('Expand content', 'casamia'),
					"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'casamia') ),
					"refresh" => false,
					"std" => 1,
					"type" => "checkbox"
					),
	
	
				'blog_widgets_info' => array(
					"title" => esc_html__('Additional widgets', 'casamia'),
					"desc" => '',
					"type" => CASAMIA_THEME_FREE ? "hidden" : "info",
					),
				'widgets_above_page_blog' => array(
					"title" => esc_html__('Widgets at the top of the page', 'casamia'),
					"desc" => wp_kses_data( __('Select widgets to show at the top of the page (above content and sidebar)', 'casamia') ),
					"std" => 'hide',
					"options" => array(),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
					),
				'widgets_above_content_blog' => array(
					"title" => esc_html__('Widgets above the content', 'casamia'),
					"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'casamia') ),
					"std" => 'hide',
					"options" => array(),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
					),
				'widgets_below_content_blog' => array(
					"title" => esc_html__('Widgets below the content', 'casamia'),
					"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'casamia') ),
					"std" => 'hide',
					"options" => array(),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
					),
				'widgets_below_page_blog' => array(
					"title" => esc_html__('Widgets at the bottom of the page', 'casamia'),
					"desc" => wp_kses_data( __('Select widgets to show at the bottom of the page (below content and sidebar)', 'casamia') ),
					"std" => 'hide',
					"options" => array(),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
					),

				'blog_advanced_info' => array(
					"title" => esc_html__('Advanced settings', 'casamia'),
					"desc" => '',
					"type" => "info",
					),
				'no_image' => array(
					"title" => esc_html__('Image placeholder', 'casamia'),
					"desc" => wp_kses_data( __('Select or upload an image used as placeholder for posts without a featured image', 'casamia') ),
					"std" => '',
					"type" => "image"
					),
				'time_diff_before' => array(
					"title" => esc_html__('Easy Readable Date Format', 'casamia'),
					"desc" => wp_kses_data( __("For how many days to show the easy-readable date format (e.g. '3 days ago') instead of the standard publication date", 'casamia') ),
					"std" => 5,
					"type" => "text"
					),
				'sticky_style' => array(
					"title" => esc_html__('Sticky posts style', 'casamia'),
					"desc" => wp_kses_data( __('Select style of the sticky posts output', 'casamia') ),
					"std" => 'inherit',
					"options" => array(
						'inherit' => esc_html__('Decorated posts', 'casamia'),
						'columns' => esc_html__('Mini-cards',	'casamia')
					),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
					),
				"blog_animation" => array( 
					"title" => esc_html__('Animation for the posts', 'casamia'),
					"desc" => wp_kses_data( __('Select animation to show posts in the blog. Attention! Do not use any animation on pages with the "wheel to the anchor" behaviour (like a "Chess 2 columns")!', 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"std" => "none",
					"options" => array(),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
					),
				'meta_parts' => array(
					"title" => esc_html__('Post meta', 'casamia'),
					"desc" => wp_kses_data( __("If your blog page is created using the 'Blog archive' page template, set up the 'Post Meta' settings in the 'Theme Options' section of that page.", 'casamia') )
								. '<br>'
								. wp_kses_data( __("<b>Tip:</b> Drag items to change their order.", 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'categories=1|date=1|counters=1|author=0|share=0|edit=1',
					"options" => array(
						'categories' => esc_html__('Categories', 'casamia'),
						'date'		 => esc_html__('Post date', 'casamia'),
						'author'	 => esc_html__('Post author', 'casamia'),
						'counters'	 => esc_html__('Views, Likes and Comments', 'casamia'),
						'share'		 => esc_html__('Share links', 'casamia'),
						'edit'		 => esc_html__('Edit link', 'casamia')
					),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "checklist"
				),
				'counters' => array(
					"title" => esc_html__('Views, Likes and Comments', 'casamia'),
					"desc" => wp_kses_data( __("Likes and Views are available only if ThemeREX Addons is active", 'casamia') ),
					"override" => array(
						'mode' => 'page',
						'section' => esc_html__('Content', 'casamia')
					),
					"dependency" => array(
                        '#page_template' => array( 'blog.php' ),
                        '.editor-page-attributes__template select' => array( 'blog.php' ),
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'views=1|likes=1|comments=1',
					"options" => array(
						'views' => esc_html__('Views', 'casamia'),
						'likes' => esc_html__('Likes', 'casamia'),
						'comments' => esc_html__('Comments', 'casamia')
					),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "checklist"
				),

				
				// Blog - Single posts
				'blog_single' => array(
					"title" => esc_html__('Single posts', 'casamia'),
					"desc" => wp_kses_data( __('Settings of the single post', 'casamia') ),
					"type" => "section",
					),
				'hide_featured_on_single' => array(
					"title" => esc_html__('Hide featured image on the single post', 'casamia'),
					"desc" => wp_kses_data( __("Hide featured image on the single post's pages", 'casamia') ),
					"override" => array(
						'mode' => 'page,post',
						'section' => esc_html__('Content', 'casamia')
					),
					"std" => 0,
					"type" => "checkbox"
					),
				'hide_sidebar_on_single' => array(
					"title" => esc_html__('Hide sidebar on the single post', 'casamia'),
					"desc" => wp_kses_data( __("Hide sidebar on the single post's pages", 'casamia') ),
					"std" => 0,
					"type" => "checkbox"
					),
				'show_post_meta' => array(
					"title" => esc_html__('Show post meta', 'casamia'),
					"desc" => wp_kses_data( __("Display block with post's meta: date, categories, counters, etc.", 'casamia') ),
					"std" => 0,
					"type" => "checkbox"
					),
				'meta_parts_post' => array(
					"title" => esc_html__('Post meta', 'casamia'),
					"desc" => wp_kses_data( __("Meta parts for single posts.", 'casamia') ),
					"dependency" => array(
						'show_post_meta' => array(1)
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'categories=1|date=1|counters=1|author=0|share=0|edit=1',
					"options" => array(
						'categories' => esc_html__('Categories', 'casamia'),
						'date'		 => esc_html__('Post date', 'casamia'),
						'author'	 => esc_html__('Post author', 'casamia'),
						'counters'	 => esc_html__('Views, Likes and Comments', 'casamia'),
						'share'		 => esc_html__('Share links', 'casamia'),
						'edit'		 => esc_html__('Edit link', 'casamia')
					),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "checklist"
				),
				'counters_post' => array(
					"title" => esc_html__('Views, Likes and Comments', 'casamia'),
					"desc" => wp_kses_data( __("Likes and Views are available only if ThemeREX Addons is active", 'casamia') ),
					"dependency" => array(
						'show_post_meta' => array(1)
					),
					"dir" => 'vertical',
					"sortable" => true,
					"std" => 'views=1|likes=1|comments=1',
					"options" => array(
						'views' => esc_html__('Views', 'casamia'),
						'likes' => esc_html__('Likes', 'casamia'),
						'comments' => esc_html__('Comments', 'casamia')
					),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "checklist"
				),
				'show_share_links' => array(
					"title" => esc_html__('Show share links', 'casamia'),
					"desc" => wp_kses_data( __("Display share links on the single post", 'casamia') ),
					"std" => 1,
					"type" => "checkbox"
					),
				'show_author_info' => array(
					"title" => esc_html__('Show author info', 'casamia'),
					"desc" => wp_kses_data( __("Display block with information about post's author", 'casamia') ),
					"std" => 1,
					"type" => "checkbox"
					),
				'blog_single_related_info' => array(
					"title" => esc_html__('Related posts', 'casamia'),
					"desc" => '',
					"type" => "info",
					),
				'show_related_posts' => array(
					"title" => esc_html__('Show related posts', 'casamia'),
					"desc" => wp_kses_data( __("Show section 'Related posts' on the single post's pages", 'casamia') ),
					"override" => array(
						'mode' => 'page,post',
						'section' => esc_html__('Content', 'casamia')
					),
					"std" => 0,
					"type" => "checkbox"
					),
				'related_posts' => array(
					"title" => esc_html__('Related posts', 'casamia'),
					"desc" => wp_kses_data( __('How many related posts should be displayed in the single post? If 0 - no related posts shown.', 'casamia') ),
					"dependency" => array(
						'show_related_posts' => array(1)
					),
					"std" => 2,
					"options" => casamia_get_list_range(1,9),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
					),
				'related_columns' => array(
					"title" => esc_html__('Related columns', 'casamia'),
					"desc" => wp_kses_data( __('How many columns should be used to output related posts in the single page (from 2 to 4)?', 'casamia') ),
					"dependency" => array(
						'show_related_posts' => array(1)
					),
					"std" => 2,
					"options" => casamia_get_list_range(1,4),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "switch"
					),
				'related_style' => array(
					"title" => esc_html__('Related posts style', 'casamia'),
					"desc" => wp_kses_data( __('Select style of the related posts output', 'casamia') ),
					"dependency" => array(
						'show_related_posts' => array(1)
					),
					"std" => 2,
					"options" => casamia_get_list_styles(1,2),
					"type" => CASAMIA_THEME_FREE ? "hidden" : "switch"
					),
			'blog_end' => array(
				"type" => "panel_end",
				),
			
		
		
			// 'Colors'
			'panel_colors' => array(
				"title" => esc_html__('Colors', 'casamia'),
				"desc" => '',
				"priority" => 300,
				"type" => "section"
				),

			'color_schemes_info' => array(
				"title" => esc_html__('Color schemes', 'casamia'),
				"desc" => wp_kses_data( __('Color schemes for various parts of the site. "Inherit" means that this block is used the Site color scheme (the first parameter)', 'casamia') ),
				"type" => "info",
				),
			'color_scheme' => array(
				"title" => esc_html__('Site Color Scheme', 'casamia'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'casamia')
				),
				"std" => 'default',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),
			'sidebar_scheme' => array(
				"title" => esc_html__('Sidebar Color Scheme', 'casamia'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'casamia')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),
			'header_scheme' => array(
				"title" => esc_html__('Header Color Scheme', 'casamia'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'casamia')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),
			'menu_scheme' => array(
				"title" => esc_html__('Menu Color Scheme', 'casamia'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'casamia')
				),
				"std" => 'inherit',
				"options" => array(),
				"refresh" => false,
				"type" => CASAMIA_THEME_FREE ? "hidden" : "switch"
				),
			'footer_scheme' => array(
				"title" => esc_html__('Footer Color Scheme', 'casamia'),
				"desc" => '',
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_cars,cpt_properties,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Colors', 'casamia')
				),
				"std" => 'dark',
				"options" => array(),
				"refresh" => false,
				"type" => "switch"
				),

			'color_scheme_editor_info' => array(
				"title" => esc_html__('Color scheme editor', 'casamia'),
				"desc" => wp_kses_data(__('Select color scheme to modify. Attention! Only those sections in the site will be changed which this scheme was assigned to', 'casamia') ),
				"type" => "info",
				),
			'scheme_storage' => array(
				"title" => esc_html__('Color scheme editor', 'casamia'),
				"desc" => '',
				"std" => '$casamia_get_scheme_storage',
				"refresh" => false,
				"colorpicker" => "tiny",
				"type" => "scheme_editor"
				),


			// 'Hidden'
			'media_title' => array(
				"title" => esc_html__('Media title', 'casamia'),
				"desc" => wp_kses_data( __('Used as title for the audio and video item in this post', 'casamia') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Content', 'casamia')
				),
				"hidden" => true,
				"std" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "text"
				),
			'media_author' => array(
				"title" => esc_html__('Media author', 'casamia'),
				"desc" => wp_kses_data( __('Used as author name for the audio and video item in this post', 'casamia') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Content', 'casamia')
				),
				"hidden" => true,
				"std" => '',
				"type" => CASAMIA_THEME_FREE ? "hidden" : "text"
				),


			// Internal options.
			// Attention! Don't change any options in the section below!
			'reset_options' => array(
				"title" => '',
				"desc" => '',
				"std" => '0',
				"type" => "hidden",
				),

			'last_option' => array(
				"title" => '',
				"desc" => '',
				"std" => 1,
				"type" => "hidden",
				),

		));


		// Prepare panel 'Fonts'
		$fonts = array(
		
			// 'Fonts'
			'fonts' => array(
				"title" => esc_html__('Typography', 'casamia'),
				"desc" => '',
				"priority" => 200,
				"type" => "panel"
				),

			// Fonts - Load_fonts
			'load_fonts' => array(
				"title" => esc_html__('Load fonts', 'casamia'),
				"desc" => wp_kses_data( __('Specify fonts to load when theme start. You can use them in the base theme elements: headers, text, menu, links, input fields, etc.', 'casamia') )
						. '<br>'
						. wp_kses_data( __('<b>Attention!</b> Press "Refresh" button to reload preview area after the all fonts are changed', 'casamia') ),
				"type" => "section"
				),
			'load_fonts_subset' => array(
				"title" => esc_html__('Google fonts subsets', 'casamia'),
				"desc" => wp_kses_data( __('Specify comma separated list of the subsets which will be load from Google fonts', 'casamia') )
						. '<br>'
						. wp_kses_data( __('Available subsets are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese', 'casamia') ),
				"class" => "casamia_column-1_3 casamia_new_row",
				"refresh" => false,
				"std" => '$casamia_get_load_fonts_subset',
				"type" => "text"
				)
		);

		for ($i=1; $i<=casamia_get_theme_setting('max_load_fonts'); $i++) {
			if (casamia_get_value_gp('page') != 'theme_options') {
				$fonts["load_fonts-{$i}-info"] = array(
					"title" => esc_html(sprintf(esc_html__('Font %s', 'casamia'), $i)),
					"desc" => '',
					"type" => "info",
					);
			}
			$fonts["load_fonts-{$i}-name"] = array(
				"title" => esc_html__('Font name', 'casamia'),
				"desc" => '',
				"class" => "casamia_column-1_3 casamia_new_row",
				"refresh" => false,
				"std" => '$casamia_get_load_fonts_option',
				"type" => "text"
				);
			$fonts["load_fonts-{$i}-family"] = array(
				"title" => esc_html__('Font family', 'casamia'),
				"desc" => $i==1 
							? wp_kses_data( __('Select font family to use it if font above is not available', 'casamia') )
							: '',
				"class" => "casamia_column-1_3",
				"refresh" => false,
				"std" => '$casamia_get_load_fonts_option',
				"options" => array(
					'inherit' => esc_html__("Inherit", 'casamia'),
					'serif' => esc_html__('serif', 'casamia'),
					'sans-serif' => esc_html__('sans-serif', 'casamia'),
					'monospace' => esc_html__('monospace', 'casamia'),
					'cursive' => esc_html__('cursive', 'casamia'),
					'fantasy' => esc_html__('fantasy', 'casamia')
				),
				"type" => "select"
				);
			$fonts["load_fonts-{$i}-styles"] = array(
				"title" => esc_html__('Font styles', 'casamia'),
				"desc" => $i==1 
							? wp_kses_data( __('Font styles used only for the Google fonts. This is a comma separated list of the font weight and styles. For example: 400,400italic,700', 'casamia') )
								. '<br>'
								. wp_kses_data( __('<b>Attention!</b> Each weight and style increase download size! Specify only used weights and styles.', 'casamia') )
							: '',
				"class" => "casamia_column-1_3",
				"refresh" => false,
				"std" => '$casamia_get_load_fonts_option',
				"type" => "text"
				);
		}
		$fonts['load_fonts_end'] = array(
			"type" => "section_end"
			);

		// Fonts - H1..6, P, Info, Menu, etc.
		$theme_fonts = casamia_get_theme_fonts();
		foreach ($theme_fonts as $tag=>$v) {
			$fonts["{$tag}_section"] = array(
				"title" => !empty($v['title']) 
								? $v['title'] 
								: esc_html(sprintf(esc_html__('%s settings', 'casamia'), $tag)),
				"desc" => !empty($v['description']) 
								? $v['description'] 
								: wp_kses_post( sprintf(__('Font settings of the "%s" tag.', 'casamia'), $tag) ),
				"type" => "section",
				);
	
			foreach ($v as $css_prop=>$css_value) {
				if (in_array($css_prop, array('title', 'description'))) continue;
				$options = '';
				$type = 'text';
				$title = ucfirst(str_replace('-', ' ', $css_prop));
				if ($css_prop == 'font-family') {
					$type = 'select';
					$options = array();
				} else if ($css_prop == 'font-weight') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'casamia'),
						'100' => esc_html__('100 (Light)', 'casamia'), 
						'200' => esc_html__('200 (Light)', 'casamia'), 
						'300' => esc_html__('300 (Thin)',  'casamia'),
						'400' => esc_html__('400 (Normal)', 'casamia'),
						'500' => esc_html__('500 (Semibold)', 'casamia'),
						'600' => esc_html__('600 (Semibold)', 'casamia'),
						'700' => esc_html__('700 (Bold)', 'casamia'),
						'800' => esc_html__('800 (Black)', 'casamia'),
						'900' => esc_html__('900 (Black)', 'casamia')
					);
				} else if ($css_prop == 'font-style') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'casamia'),
						'normal' => esc_html__('Normal', 'casamia'), 
						'italic' => esc_html__('Italic', 'casamia')
					);
				} else if ($css_prop == 'text-decoration') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'casamia'),
						'none' => esc_html__('None', 'casamia'), 
						'underline' => esc_html__('Underline', 'casamia'),
						'overline' => esc_html__('Overline', 'casamia'),
						'line-through' => esc_html__('Line-through', 'casamia')
					);
				} else if ($css_prop == 'text-transform') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'casamia'),
						'none' => esc_html__('None', 'casamia'), 
						'uppercase' => esc_html__('Uppercase', 'casamia'),
						'lowercase' => esc_html__('Lowercase', 'casamia'),
						'capitalize' => esc_html__('Capitalize', 'casamia')
					);
				}
				$fonts["{$tag}_{$css_prop}"] = array(
					"title" => $title,
					"desc" => '',
					"class" => "casamia_column-1_5",
					"refresh" => false,
					"std" => '$casamia_get_theme_fonts_option',
					"options" => $options,
					"type" => $type
				);
			}
			
			$fonts["{$tag}_section_end"] = array(
				"type" => "section_end"
				);
		}

		$fonts['fonts_end'] = array(
			"type" => "panel_end"
			);

		// Add fonts parameters to Theme Options
		casamia_storage_set_array_before('options', 'panel_colors', $fonts);

		// Add Header Video if WP version < 4.7
		if (!function_exists('get_header_video_url')) {
			casamia_storage_set_array_after('options', 'header_image_override', 'header_video', array(
				"title" => esc_html__('Header video', 'casamia'),
				"desc" => wp_kses_data( __("Select video to use it as background for the header", 'casamia') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'casamia')
				),
				"std" => '',
				"type" => "video"
				)
			);
		}
	}
}


// Returns a list of options that can be overridden for CPT
if (!function_exists('casamia_options_get_list_cpt_options')) {
	function casamia_options_get_list_cpt_options($cpt, $title='') {
		if (empty($title)) $title = ucfirst($cpt);
		return array(
					"header_info_{$cpt}" => array(
						"title" => esc_html__('Header', 'casamia'),
						"desc" => '',
						"type" => "info",
						),
					"header_style_{$cpt}" => array(
						"title" => esc_html__('Header style', 'casamia'),
						"desc" => wp_kses_data( sprintf(__('Select style to display the site header on the %s pages', 'casamia'), $title) ),
						"std" => 'inherit',
						"options" => array(),
						"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
						),
					"header_position_{$cpt}" => array(
						"title" => esc_html__('Header position', 'casamia'),
						"desc" => wp_kses_data( sprintf(__('Select position to display the site header on the %s pages', 'casamia'), $title) ),
						"std" => 'inherit',
						"options" => array(),
						"type" => CASAMIA_THEME_FREE ? "hidden" : "switch"
						),
					"header_image_override_{$cpt}" => array(
						"title" => esc_html__('Header image override', 'casamia'),
						"desc" => wp_kses_data( __("Allow override the header image with the post's featured image", 'casamia') ),
						"std" => 0,
						"type" => CASAMIA_THEME_FREE ? "hidden" : "checkbox"
						),
					"header_widgets_{$cpt}" => array(
						"title" => esc_html__('Header widgets', 'casamia'),
						"desc" => wp_kses_data( sprintf(__('Select set of widgets to show in the header on the %s pages', 'casamia'), $title) ),
						"std" => 'hide',
						"options" => array(),
						"type" => "select"
						),
						
					"sidebar_info_{$cpt}" => array(
						"title" => esc_html__('Sidebar', 'casamia'),
						"desc" => '',
						"type" => "info",
						),
					"sidebar_position_{$cpt}" => array(
						"title" => esc_html__('Sidebar position', 'casamia'),
						"desc" => wp_kses_data( sprintf(__('Select position to show sidebar on the %s pages', 'casamia'), $title) ),
						"refresh" => false,
						"std" => 'left',
						"options" => array(),
						"type" => "switch"
						),
					"sidebar_widgets_{$cpt}" => array(
						"title" => esc_html__('Sidebar widgets', 'casamia'),
						"desc" => wp_kses_data( sprintf(__('Select sidebar to show on the %s pages', 'casamia'), $title) ),
						"dependency" => array(
							"sidebar_position_{$cpt}" => array('left', 'right')
						),
						"std" => 'hide',
						"options" => array(),
						"type" => "select"
						),
					"hide_sidebar_on_single_{$cpt}" => array(
						"title" => esc_html__('Hide sidebar on the single pages', 'casamia'),
						"desc" => wp_kses_data( __("Hide sidebar on the single page", 'casamia') ),
						"std" => 0,
						"type" => "checkbox"
						),
						
					"footer_info_{$cpt}" => array(
						"title" => esc_html__('Footer', 'casamia'),
						"desc" => '',
						"type" => "info",
						),
					'footer_style_{$cpt}' => array(
						"title" => esc_html__('Footer style', 'casamia'),
						"desc" => wp_kses_data( __('Select style to display the site footer', 'casamia') ),
						"std" => 'inherit',
						"options" => array(),
						"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
						),
					"footer_widgets_{$cpt}" => array(
						"title" => esc_html__('Footer widgets', 'casamia'),
						"desc" => wp_kses_data( __('Select set of widgets to show in the footer', 'casamia') ),
						"std" => 'footer_widgets',
						"options" => array(),
						"type" => "select"
						),
					"footer_columns_{$cpt}" => array(
						"title" => esc_html__('Footer columns', 'casamia'),
						"desc" => wp_kses_data( __('Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'casamia') ),
						"dependency" => array(
							"footer_widgets_{$cpt}" => array('^hide')
						),
						"std" => 3,
						"options" => casamia_get_list_range(0,6),
						"type" => "select"
						),
					"footer_wide_{$cpt}" => array(
						"title" => esc_html__('Footer fullwide', 'casamia'),
						"desc" => wp_kses_data( __('Do you want to stretch the footer to the entire window width?', 'casamia') ),
						"std" => 0,
						"type" => "checkbox"
						),
						
					"widgets_info_{$cpt}" => array(
						"title" => esc_html__('Additional panels', 'casamia'),
						"desc" => '',
						"type" => CASAMIA_THEME_FREE ? "hidden" : "info",
						),
					"widgets_above_page_{$cpt}" => array(
						"title" => esc_html__('Widgets at the top of the page', 'casamia'),
						"desc" => wp_kses_data( __('Select widgets to show at the top of the page (above content and sidebar)', 'casamia') ),
						"std" => 'hide',
						"options" => array(),
						"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
						),
					"widgets_above_content_{$cpt}" => array(
						"title" => esc_html__('Widgets above the content', 'casamia'),
						"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'casamia') ),
						"std" => 'hide',
						"options" => array(),
						"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
						),
					"widgets_below_content_{$cpt}" => array(
						"title" => esc_html__('Widgets below the content', 'casamia'),
						"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'casamia') ),
						"std" => 'hide',
						"options" => array(),
						"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
						),
					"widgets_below_page_{$cpt}" => array(
						"title" => esc_html__('Widgets at the bottom of the page', 'casamia'),
						"desc" => wp_kses_data( __('Select widgets to show at the bottom of the page (below content and sidebar)', 'casamia') ),
						"std" => 'hide',
						"options" => array(),
						"type" => CASAMIA_THEME_FREE ? "hidden" : "select"
						)
					);
	}
}


// Return lists with choises when its need in the admin mode
if (!function_exists('casamia_options_get_list_choises')) {
	add_filter('casamia_filter_options_get_list_choises', 'casamia_options_get_list_choises', 10, 2);
	function casamia_options_get_list_choises($list, $id) {
		if (is_array($list) && count($list)==0) {
			if (strpos($id, 'header_style')===0)
				$list = casamia_get_list_header_styles(strpos($id, 'header_style_')===0);
			else if (strpos($id, 'header_position')===0)
				$list = casamia_get_list_header_positions(strpos($id, 'header_position_')===0);
			else if (strpos($id, 'header_widgets')===0)
				$list = casamia_get_list_sidebars(strpos($id, 'header_widgets_')===0, true);
			else if (substr($id, -7) == '_scheme')
				$list = casamia_get_list_schemes($id!='color_scheme');
			else if (strpos($id, 'sidebar_widgets')===0)
				$list = casamia_get_list_sidebars(strpos($id, 'sidebar_widgets_')===0, true);
			else if (strpos($id, 'sidebar_position')===0)
				$list = casamia_get_list_sidebars_positions(strpos($id, 'sidebar_position_')===0);
			else if (strpos($id, 'widgets_above_page')===0)
				$list = casamia_get_list_sidebars(strpos($id, 'widgets_above_page_')===0, true);
			else if (strpos($id, 'widgets_above_content')===0)
				$list = casamia_get_list_sidebars(strpos($id, 'widgets_above_content_')===0, true);
			else if (strpos($id, 'widgets_below_page')===0)
				$list = casamia_get_list_sidebars(strpos($id, 'widgets_below_page_')===0, true);
			else if (strpos($id, 'widgets_below_content')===0)
				$list = casamia_get_list_sidebars(strpos($id, 'widgets_below_content_')===0, true);
			else if (strpos($id, 'footer_style')===0)
				$list = casamia_get_list_footer_styles(strpos($id, 'footer_style_')===0);
			else if (strpos($id, 'footer_widgets')===0)
				$list = casamia_get_list_sidebars(strpos($id, 'footer_widgets_')===0, true);
			else if (strpos($id, 'blog_style')===0)
				$list = casamia_get_list_blog_styles(strpos($id, 'blog_style_')===0);
			else if (strpos($id, 'post_type')===0)
				$list = casamia_get_list_posts_types();
			else if (strpos($id, 'parent_cat')===0)
				$list = casamia_array_merge(array(0 => esc_html__('- Select category -', 'casamia')), casamia_get_list_categories());
			else if (strpos($id, 'blog_animation')===0)
				$list = casamia_get_list_animations_in();
			else if ($id == 'color_scheme_editor')
				$list = casamia_get_list_schemes();
			else if (strpos($id, '_font-family') > 0)
				$list = casamia_get_list_load_fonts(true);
		}
		return $list;
	}
}
?>